# pylint: disable=unused-wildcard-import, wildcard-import
from apian.app import *
from apian.config import *
from apian.auth import *

__all__ = ["create_api", "create_app", "read_config", "authenticated"]



"""
Read configuration from a location determined by the library.
"""
import logging
import logging.config
import os
from functools import lru_cache

import miniscule
import yaml

log = logging.getLogger(__name__)


@lru_cache(maxsize=1)
def read_config(path=None):
    """Read configuration from a prespecified location: the contents of the
    CONFIG environment variable, or top-level config.yaml.  Wraps the `miniscule
    <https://pypi.org/project/miniscule/>`_ package, and uses its mechanism to
    resolve YAML tags.

    :param path: Override the default path specified in the environment
        variable.

    :returns: A Python dictionary with configuration information.  The path of
              the configuration file is under the key `__path`.
    """
    path = path or os.environ.get("CONFIG", "config.yaml")
    try:
        config = miniscule.read_config(path)
        config["__path"] = path
        return config
    except FileNotFoundError:
        print("No file at", path)
        return None


def init_logging(path):
    # Let the application take care of logging
    logging.getLogger("werkzeug").handlers = []
    if path is None:
        return

    with open(path, "r") as handle:
        log_config = yaml.load(handle.read(), Loader=yaml.SafeLoader)
        logging.config.dictConfig(log_config)



import re

import setuptools


def read_file(path):
    with open(path, "r") as handle:
        return handle.read()


def read_version():
    try:
        s = read_file("VERSION")
        m = re.match(r"v(\d+\.\d+\.\d+(-.*)?)", s)
        return m.group(1)
    except FileNotFoundError:
        return "0.0.0"


long_description = read_file("docs/source/description.rst")
version = read_version()

setuptools.setup(
    name="apian",
    description="""
    Small, opinionated library for building REST APIs.""",
    keywords="rest http web",
    long_description=long_description,
    include_package_data=True,
    version=version,
    url="https://gitlab.com/greenhousegroup/ai/libraries/apian/",
    author="Greenhouse AI team",
    author_email="ai@greenhousegroup.com",
    package_dir={"apian": "src/apian"},
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
    ],
    install_requires=[
        "werkzeug < 1.0.0",  # Due to mismatch flask-restplus
        "flask-restplus >= 0.13.0, < 2.0.0",
        "miniscule >= 0.3.0,< 2.0.0",
        "PyJWT >= 1.5.3",
    ],
    data_files=[(".", ["VERSION"])],
    setup_requires=["pytest-runner"],
    tests_require=["pytest>=4", "mock>=2.0.0"],
    packages=setuptools.find_packages("src"),
)
